/**
 * AutoDAO - Generic DAO on steroids implementation for Java.
 * Copyright (C) 2008-2009  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.autodao;

import java.util.Calendar;

import org.joda.time.ReadableInstant;

/**
 * Default implementation of {@link QueryArgumentTransformer}.
 * <p/>
 * Handles Joda-Time {@link ReadableInstant} subclasses and transforms them into {@link Calendar}.
 */
public class DefaultQueryArgumentTransformer implements QueryArgumentTransformer {
  @Override
  public Object transform(final Object queryArg) {
    if (queryArg instanceof ReadableInstant) {
      final Calendar c = Calendar.getInstance();
      c.setTimeInMillis(((ReadableInstant) queryArg).getMillis());
      return c;
    } else {
      return queryArg;
    }
  }
}
